Method: AttrJson::Model#_destroy

Defined in:
lib/attr_json/model.rb

#_destroyObject

ActiveRecord objects have a _destroy, related to marked_for_destruction? functionality used with AR nested attributes. We don't mark for destruction, our nested attributes implementation just deletes immediately, but having this simple method always returning false makes things work more compatibly and smoothly with standard code for nested attributes deletion in form builders.



415
416
417
# File 'lib/attr_json/model.rb', line 415

def _destroy
  false
end